NodeNameReport class

Inheritance

Constructors

NodeNameReport(List<int> data)

Properties

command → int
no setterinherited
commandClass → int
no setterinherited
data → List<int>
finalinherited
encoding → int
The character encoding
no setter
hashCode → int
The hash code for this object.
no setterinherited
name → String?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceNode → int
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited