Nonce class

A number used once (nonce).

Constructors

Nonce(List<int> values)
Nonce.generate()
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
key → int
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
values → List<int>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited