ThermostatOperatingStateReport class

Inheritance

Properties

command → int
no setterinherited
commandClass → int
no setterinherited
data → List<int>
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceNode → int
no setterinherited
state → int
The current thermostat state as defined in ThermostatOperatingState
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited