SensorMultilevelType class

SensorMultilevelType represents the capabilities in a multilevel sensor.

Constructors

SensorMultilevelType({required int sensorTypeNum, required List<String> scaleTypeDescriptions, required String description})
Instantiate a new sensor type constant
const
SensorMultilevelType.forTypeNum(int sensorTypeNum)
Return the sensor type associated with the given sensorTypeNum. Throw a ZwException if sensorTypeNum is out of bounds.
factory

Properties

bitMask → int
no setter
bitMaskHex → String
no setter
bitNum → int
no setter
byteNum → int
no setter
description → String
A description of this sensor type
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scaleTypeDescriptions → List<String>
Descriptions for each of the sensor value scale types
final
sensorTypeNum → int
The "sensorType" field value associated with this type which is also the index of this object in the sensorMultilevelTypes list
final
sensorTypeNumHex → String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
scaleTypeDescriptionFor(int scaleTypeNum) → String
Return a description for the scale type. Throw a ZwException if scaleTypeNum is out of bounds.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited