NotificationReport class

NotificationReport decodes the COMMAND_CLASS_NOTIFICATION, NOTIFICATION_REPORT message

Inheritance

Constructors

NotificationReport(List<int> data)

Properties

command → int
no setterinherited
commandClass → int
no setterinherited
data → List<int>
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
notification → int
no setter
notificationType → int
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceNode → int
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited