SensorBinaryReport class

SensorBinaryReport decodes the COMMAND_CLASS_SENSOR_BINARY, SENSOR_BINARY_REPORT message

Inheritance

Constructors

SensorBinaryReport(List<int> data)

Properties

command → int
no setterinherited
commandClass → int
no setterinherited
data → List<int>
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceNode → int
no setterinherited
type → int?
no setter
value → int
0x00 = idle 0xFF = sensor detected an event
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited