SensorMultilevelReport class

SensorMultilevelReport decodes the COMMAND_CLASS_SENSOR_MULTILEVEL, SENSOR_MULTILEVEL_REPORT message

Inheritance

Constructors

SensorMultilevelReport(List<int> data)

Properties

command → int
no setterinherited
commandClass → int
no setterinherited
data → List<int>
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
precision → int
The # of decimal places in the value
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scale → int
An identifier indicating the scale associated with the value being reported
no setter
sensorType → SensorMultilevelType
The type of sensor whose value is being reported
no setter
sourceNode → int
no setterinherited
type → int
An identifier indicating the type of sensor whose value is being reported
no setter
units → String
A description of the scale associated with the value being reported
no setter
value → num
The value being reported
no setter
valueSize → int
The # of bytes comprising the value = 1, 2, 4
no setter
valueWithUnits → String
The value followed by the units or scale associated with the value
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited